@@ -60,7 +60,6 @@ import com.openexchange.subscribe.crawler.internal.AbstractStep;
 import com.openexchange.subscribe.crawler.internal.ContactSanitizer;
 import com.openexchange.subscribe.crawler.internal.Mappings;
 import com.openexchange.subscribe.crawler.internal.PagePartSequence;
-import com.openexchange.tools.versit.converter.ConverterException;
 
 
 /**
@@ -101,9 +100,8 @@ public class ContactObjectsByStringAndPagePartSequenceStep extends AbstractStep<
                     contactObjects.add(contact);
                 }
 
-            } catch (final ConverterException e) {
+            } catch (final OXException e) {
                 LOG.error("{} for Context : {}, User : {}, Folder : {}.", e.getMessage(), workflow.getSubscription().getContext().getContextId(), workflow.getSubscription().getUserId(), workflow.getSubscription().getFolderId());
-
                 exception = e;
             }
             executedSuccessfully = true;
